@@ -35,10 +35,18 @@ class ELBV2ListernerRuleECS(elbv2.ListenerRule):
                             f'{mapname}PathPattern')})
                     ]
                 ))
+            if 'RequestMethod' in key:
+                self.Conditions.append(elbv2.Condition(
+                    Field='http-request-method',
+                    HttpRequestMethodConfig=elbv2.HttpRequestMethodConfig(
+                        Values=[get_endvalue(
+                            f'{mapname}RequestMethod', issub=True)])
+                ))
         if 'Actions' not in key:
+            tg_prefix = key.get('TargetGroupPrefix', '')
             self.Actions = [elbv2.Action(
                 Type='forward',
-                TargetGroupArn=Ref(f'TargetGroup{scheme}')
+                TargetGroupArn=Ref(f'TargetGroup{tg_prefix}{scheme}')
             )]
         self.Priority = get_endvalue(f'{mapname}Priority')
 
@@ -81,6 +89,11 @@ def LB_ListenersEC2():
 
 
 def LB_ListenerRulesExternalInternal(index, key, mapname, scheme):
+    # Skip if Rule is only for External/Internal
+    only_scheme = key.get('Scheme')
+    if only_scheme and only_scheme != scheme:
+        return
+
     # resources
     R_RuleHttp = ELBV2ListernerRuleECS(
         f'ListenerHttp{scheme}Rules{index}',
@@ -245,29 +258,33 @@ def LB_ListenersV2ECS():
 
 
 def LB_TargetGroupsEC2():
-    for n in ['External', 'Internal']:
+    for n in cfg.ElasticLoadBalancingV2TargetGroupEC2:
         # resources
         if n not in cfg.LoadBalancerApplication:
             continue
         r_TG = elbv2.TargetGroup(f'TargetGroup{n}')
         auto_get_props(r_TG,
-                       mapname=f'ElasticLoadBalancingV2TargetGroupEC2')
+                       mapname=f'ElasticLoadBalancingV2TargetGroupEC2{n}')
         add_obj(r_TG)
 
         cfg.Alarm[f'TargetEC2{n}5XX']['IBOX_ENABLED'] = True
 
 
 def LB_TargetGroupsECS():
-    for n in ['External', 'Internal']:
+    for n in cfg.ElasticLoadBalancingV2TargetGroupECS:
         # resources
-        if n not in cfg.LoadBalancerApplication:
+        if (n in ['External', 'Internal']
+                and n not in cfg.LoadBalancerApplication):
             continue
         r_TG = elbv2.TargetGroup(f'TargetGroup{n}')
         auto_get_props(r_TG,
-                       mapname=f'ElasticLoadBalancingV2TargetGroupECS')
+                       mapname=f'ElasticLoadBalancingV2TargetGroupECS{n}')
         add_obj(r_TG)
 
-        cfg.Alarm[f'Target{n}5XX']['IBOX_ENABLED'] = True
+        try:
+            cfg.Alarm[f'Target{n}5XX']['IBOX_ENABLED'] = True
+        except Exception:
+            pass
 
 
 def LB_TargetGroupsALB():
@@ -275,13 +292,13 @@ def LB_TargetGroupsALB():
     lambda_arn = get_expvalue(f'Lambda{lambda_name}Arn')
     perm_name = f'LambdaPermission{lambda_name}LoadBalancerApplication'
 
-    for n in ['External', 'Internal']:
+    for n in cfg.ElasticLoadBalancingV2TargetGroupALB:
         # resources
         if n not in cfg.LoadBalancerApplication:
             continue
         r_TG = elbv2.TargetGroup(f'TargetGroupServiceUnavailable{n}')
         auto_get_props(r_TG,
-                       mapname=f'ElasticLoadBalancingV2TargetGroupALB')
+                       mapname=f'ElasticLoadBalancingV2TargetGroupALB{n}')
         r_TG.DependsOn = f'{perm_name}{n}'
         r_TG.Condition = f'LoadBalancerApplication{n}'
 
