@@ -111,11 +111,11 @@ def RDS_DB(key):
     for n, v in getattr(cfg, key).items():
         mapname = f'{key}{n}'
 
-        if not v['IBOXENABLED']:
+        if not v['IBOX_ENABLED']:
             continue
 
         try:
-            resname = v['IBOXRESNAME']
+            resname = v['IBOX_RESNAME']
         except Exception:
             resname = mapname
 
