@@ -58,13 +58,6 @@ class SecurityGroupRuleEcsService(SecurityGroupRule):
 
 
 def SG_SecurityGroupsExtra(Out_String, Out_Map):
-    # if key SecurityGroups not present,
-    # set and empty SecurityGroups list and output (not added)
-    try:
-        cfg.SecurityGroups
-    except Exception:
-        return []
-
     # Parameters
     P_SecurityGroups = Parameter('SecurityGroups')
     P_SecurityGroups.Description = (
@@ -88,7 +81,7 @@ def SG_SecurityGroupsExtra(Out_String, Out_Map):
 
         # conditions
         add_obj({name: Not(get_condition(
-            '', 'equals', 'None', Select(n, Split(',', 'SecurityGroups'))))})
+            '', 'equals', 'none', Select(n, Split(',', 'SecurityGroups'))))})
 
         SecurityGroups.append(If(
             name,
@@ -102,7 +95,7 @@ def SG_SecurityGroupsExtra(Out_String, Out_Map):
             outvaluename: If(
                 name,
                 get_expvalue(value, prefix='SecurityGroup'),
-                'None')})
+                'none')})
 
     # Outputs
     O_SecurityGroups = Output('SecurityGroups')
@@ -111,10 +104,10 @@ def SG_SecurityGroupsExtra(Out_String, Out_Map):
     add_obj([
         O_SecurityGroups])
 
-    return SecurityGroups
+    cfg.SecurityGroupsImport = SecurityGroups
 
 
-def SG_SecurityGroupsEC2():
+def SG_SecurityGroupsEC2(key):
     Out_String = ['Rules=${SecurityGroupInstancesRules}']
     Out_Map = {
         'SecurityGroupInstancesRules': {
@@ -130,10 +123,10 @@ def SG_SecurityGroupsEC2():
     add_obj([
         R_SGInstance])
 
-    return SG_SecurityGroupsExtra(Out_String, Out_Map)
+    SecurityGroups = SG_SecurityGroupsExtra(Out_String, Out_Map)
 
 
-def SG_SecurityGroupsECS():
+def SG_SecurityGroupsECS(key):
     Out_String = ['Service=${SecurityGroupEcsService}']
     Out_Map = {
         'SecurityGroupEcsService': {
@@ -146,10 +139,8 @@ def SG_SecurityGroupsECS():
     except Exception:
         pass
 
-    return SecurityGroups
 
-
-def SG_SecurityGroupsTSK():
+def SG_SecurityGroupsTSK(key):
     Out_String = []
     Out_Map = {}
 
@@ -160,8 +151,6 @@ def SG_SecurityGroupsTSK():
     except Exception:
         pass
 
-    return SecurityGroups
-
 
 def SG_SecurityGroupRules(groupname, ingresses):
     SecurityGroup_Rules = []
@@ -258,7 +247,7 @@ def SG_SecurityGroup(key):
 
 def SG_SecurityGroupIngresses(key):
     for n, v in getattr(cfg, key).items():
-        if not v.get('IBOXENABLED', True):
+        if not v.get('IBOX_ENABLED', True):
             continue
         resname = f'{key}{n}'
         try:
